@@ -235,6 +235,7 @@ def interpolate_wo(wo_low, wo_high, parameter, h=0.01, tag=None):
             smaller than in the input curves are used, to preserve information.
         tag (string): Tag to associate to the constructed object. If None
             it will be automatically filled. Set to empty string to ensure no tag.
+
     Returns:
         A new oil-water curve
 
@@ -247,6 +248,12 @@ def interpolate_wo(wo_low, wo_high, parameter, h=0.01, tag=None):
     assert 0 <= parameter <= 1
     # Extrapolation is refused, but perhaps later implemented with truncation to (0,1)
 
+    # Running fast mode if both interpolants have fast mode
+    if wo_low.fast and wo_high.fast:
+        fast = True
+    else:
+        fast = False
+
     # Constructs functions that works on normalized saturation interval
     krw1, kro1 = normalize_nonlinpart_wo(wo_low)
     krw2, kro2 = normalize_nonlinpart_wo(wo_high)
@@ -270,7 +277,7 @@ def interpolate_wo(wo_low, wo_high, parameter, h=0.01, tag=None):
 
     # Construct the new WaterOil object, with interpolated
     # endpoints:
-    wo_new = pyscal.WaterOil(swl=swl_new, swcr=swcr_new, sorw=sorw_new, h=h)
+    wo_new = pyscal.WaterOil(swl=swl_new, swcr=swcr_new, sorw=sorw_new, h=h, fast=fast)
 
     # Add interpolated relperm data in nonlinear parts:
     wo_new.table["krw"] = weighted_value(
@@ -317,6 +324,7 @@ def interpolate_go(go_low, go_high, parameter, h=0.01, tag=None):
             smaller than in the input curves are used, to preserve information.
         tag (string): Tag to associate to the constructed object. If None
             it will be automatically filled. Set to empty string to ensure no tag.
+
     Returns:
         A new gas-oil curve
 
@@ -329,6 +337,12 @@ def interpolate_go(go_low, go_high, parameter, h=0.01, tag=None):
     assert 0 <= parameter <= 1
     # Extrapolation is refused, but perhaps later implemented with truncation to (0,1)
 
+    # Running fast mode if both interpolants have fast mode
+    if go_low.fast and go_high.fast:
+        fast = True
+    else:
+        fast = False
+
     # Constructs functions that works on normalized saturation interval
     krg1, kro1 = normalize_nonlinpart_go(go_low)
     krg2, kro2 = normalize_nonlinpart_go(go_high)
@@ -352,7 +366,7 @@ def interpolate_go(go_low, go_high, parameter, h=0.01, tag=None):
 
     # Construct the new GasOil object, with interpolated
     # endpoints:
-    go_new = pyscal.GasOil(swl=swl_new, sgcr=sgcr_new, sorg=sorg_new, h=h)
+    go_new = pyscal.GasOil(swl=swl_new, sgcr=sgcr_new, sorg=sorg_new, h=h, fast=fast)
 
     # Add interpolated relperm data in nonlinear parts:
     go_new.table["krg"] = weighted_value(
