@@ -1,7 +1,12 @@
 """Test module for the WaterOil object"""
+import io
 
+import pandas as pd
 import numpy as np
 
+import matplotlib
+import matplotlib.pyplot
+
 from hypothesis import given, settings
 import hypothesis.strategies as st
 
@@ -130,6 +135,42 @@ def test_wateroil_krendmax(swl, swcr, sorw, kroend, krwend, krwmax, h, fast):
     assert 0 < wateroil.crosspoint() < 1
 
 
+def test_fast():
+    """Test the fast option"""
+    # First without fast:
+    wateroil = WaterOil(h=0.1)
+    wateroil.add_corey_water()
+    wateroil.add_corey_oil()
+    # This crosspoint computation is only present for fast=False:
+    assert "-- krw = krow @ sw=0.5" in wateroil.SWOF()
+
+    # Provoke non-strict-monotone krow:
+    wateroil.table.loc[0:2, "krow"] = [1.00, 0.81, 0.81]
+    # (this is valid in non-imbibition, but pyscal will correct it for all
+    # curves)
+    assert "0.1000000 0.0100000 0.8100000 0.0000000" in wateroil.SWOF()
+    assert "0.2000000 0.0400000 0.8099999 0.0000000" in wateroil.SWOF()
+    #   monotonocity correction:   ^^^^^^
+
+    # Now redo with fast option:
+    wateroil = WaterOil(h=0.1, fast=True)
+    wateroil.add_corey_water()
+    wateroil.add_corey_oil()
+    # This crosspoint computation is only present for fast=False:
+    assert "-- krw = krow" not in wateroil.SWOF()
+
+    # Provoke non-strict-monotone krow, in fast-mode
+    # this slips through:
+    wateroil.table.loc[0:2, "krow"] = [1.00, 0.81, 0.81]
+    assert "0.1000000 0.0100000 0.8100000 0.0000000" in wateroil.SWOF()
+    assert "0.2000000 0.0400000 0.8100000 0.0000000" in wateroil.SWOF()
+    # not corrected:               ^^^^^^
+
+    wateroil.table.loc[0:2, "krw"] = [0.00, 0.01, 0.01]
+    assert "0.1000000 0.0100000" in wateroil.SWFN()
+    assert "0.2000000 0.0100000" in wateroil.SWFN()
+
+
 def test_swfn():
     """Test that we can dump SWFN without giving oil relperm"""
     wateroil = WaterOil(h=0.1)
@@ -147,7 +188,17 @@ def test_linearsegments():
     wateroil.add_corey_water(nw=10, krwend=0.5)
     check_table(wateroil.table)
     check_linear_sections(wateroil)
-    # wateroil.plotkrwkrow(marker="*")
+
+
+def test_plotting():
+    """Test that plotting code pass through (nothing displayed)"""
+    wateroil = WaterOil(swl=0.1, h=0.1)
+    wateroil.add_corey_water()
+    wateroil.add_corey_oil()
+    wateroil.plotkrwkrow(mpl_ax=matplotlib.pyplot.subplots()[1])
+
+    wateroil.add_simple_J()
+    wateroil.plotpc(mpl_ax=matplotlib.pyplot.subplots()[1])
 
 
 def test_wateroil_linear():
@@ -216,3 +267,38 @@ def test_comments():
     assert "KRW" in swof
     assert "KROW" in swof
     assert "PC" in swof
+
+
+def test_nexus():
+    """Test the Nexus export"""
+    wateroil = WaterOil(h=0.01, swl=0.1, swcr=0.3, sorw=0.3)
+    wateroil.add_corey_oil(now=10, kroend=0.5)
+    wateroil.add_corey_water(nw=10, krwend=0.5)
+    nexus_lines = wateroil.WOTABLE().splitlines()
+    non_comments = [
+        line for line in nexus_lines if not line.startswith("!") or not len(line)
+    ]
+    assert non_comments[0] == "WOTABLE"
+    assert non_comments[1] == "SW KRW KROW PC"
+    df = pd.read_table(
+        io.StringIO("\n".join(non_comments[2:])),
+        engine="python",
+        sep=r"\s+",
+        header=None,
+    )
+    assert (df.values <= 1.0).all()
+    assert (df.values >= 0.0).all()
+
+
+def test_skjaeveland_pc():
+    """Simple test of Skjæveland capillary pressure correlation"""
+    wateroil = WaterOil(h=0.3, swl=0.2)
+    wateroil.add_skjaeveland_pc(swr=0.1, cw=0.1, co=-0.1, aw=0.1, ao=0.1)
+    check_table(wateroil.table)
+
+    # Add with wrong numbers
+    wateroil = WaterOil(h=0.3, swl=0.2, sorw=0.3)
+    wateroil.add_skjaeveland_pc(swr=0.8, cw=-0.1, co=0.1, aw=-0.1, ao=-0.1)
+    # (the code returns None when errors occur, no Exception)
+    assert wateroil.pccomment == ""
+    assert "pc" not in wateroil.table
